
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysCaptcha;
import io.platform.sys.biz.service.SysCaptchaService;
import io.platform.sys.dto.SysCaptchaDto;
import io.platform.sys.service.client.api.SysCaptchaServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysCaptchaServiceClientImpl extends BaseServiceClient<SysCaptcha, SysCaptchaDto> implements SysCaptchaServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysCaptchaService sysCaptchaService;

    @Override
    public SysCaptchaDto queryObject(String id) {
        SysCaptcha sysCaptcha = sysCaptchaService.selectById(id);
        if (sysCaptcha == null) {
            return null;
        } else {
            SysCaptchaDto sysCaptchaDto = new SysCaptchaDto();
            BeanUtils.copyProperties(sysCaptcha, sysCaptchaDto);
            return sysCaptchaDto;
        }

    }

    @Override
    public List<SysCaptchaDto> queryList(Map<String, Object> map) {
        List<SysCaptcha> sysCaptchaList = sysCaptchaService.selectByMap(map);
        return convertList(sysCaptchaList, SysCaptchaDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<SysCaptcha> ew = new EntityWrapper<>();
        ew.allEq(map);
        return sysCaptchaService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(SysCaptchaDto sysCaptchaDto) {
        ExecuteResult<String> result = new ExecuteResult<>();
        try {
            SysCaptcha sysCaptcha = new SysCaptcha();
            revert(sysCaptchaDto, sysCaptcha);
//            UUID uuid = UUID.randomUUID();
//            sysCaptcha.setUuid(uuid.toString());
            boolean flag = sysCaptchaService.insert(sysCaptcha);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysCaptchaDto sysCaptchaDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysCaptcha sysCaptcha = new SysCaptcha();
            revert(sysCaptchaDto, sysCaptcha);

            boolean flag = sysCaptchaService.updateById(sysCaptcha);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(String id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysCaptchaService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<String> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysCaptchaService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysCaptchaDto> getPage(Page<SysCaptchaDto> pageDto, SysCaptchaDto sysCaptchaDto) {
        Page<SysCaptcha> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        EntityWrapper<SysCaptcha> wrapper = new EntityWrapper<>();
        SysCaptcha sysCaptcha = new SysCaptcha();
        revert(sysCaptchaDto,sysCaptcha);
        wrapper.setEntity(sysCaptcha);
        page = sysCaptchaService.selectPage(page, wrapper);
        List<SysCaptchaDto> sysCaptchaDtoList = convertList(page.getRecords(), SysCaptchaDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysCaptchaDtoList);
        return pageDto;
    }
}
