
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysRoleMenu;
import io.platform.sys.biz.service.SysRoleMenuService;
import io.platform.sys.dto.SysRoleMenuDto;
import io.platform.sys.service.client.api.SysRoleMenuServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysRoleMenuServiceClientImpl extends BaseServiceClient<SysRoleMenu, SysRoleMenuDto> implements SysRoleMenuServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysRoleMenuService sysRoleMenuService;

    @Override
    public SysRoleMenuDto queryObject(Long id) {
        SysRoleMenu sysRoleMenu = sysRoleMenuService.selectById(id);
        SysRoleMenuDto sysRoleMenuDto = new SysRoleMenuDto();
        BeanUtils.copyProperties(sysRoleMenu, sysRoleMenuDto);
        return sysRoleMenuDto;
    }

    @Override
    public List<SysRoleMenuDto> queryList(Map<String, Object> map) {
        List<SysRoleMenu> sysRoleMenuList = sysRoleMenuService.selectByMap(map);
        return convertList(sysRoleMenuList, SysRoleMenuDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<SysRoleMenu> ew = new EntityWrapper<>();
        ew.allEq(map);
        return sysRoleMenuService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(SysRoleMenuDto sysRoleMenuDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysRoleMenu sysRoleMenu = new SysRoleMenu();
            revert(sysRoleMenuDto, sysRoleMenu);
            boolean flag = sysRoleMenuService.insert(sysRoleMenu);
            if (!flag) {
                result.addErrorMessage("保存失败。");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysRoleMenuDto sysRoleMenuDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            SysRoleMenu sysRoleMenu = new SysRoleMenu();
            revert(sysRoleMenuDto, sysRoleMenu);

            boolean flag = sysRoleMenuService.updateById(sysRoleMenu);
            if (!flag) {
                result.addErrorMessage("更新失败。");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysRoleMenuService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysRoleMenuService.deleteBatchIds(ids);
            if (!flag) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysRoleMenuDto> getPage(Page<SysRoleMenuDto> pageDto, SysRoleMenuDto sysRoleMenuDto) {
        Page<SysRoleMenu> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        SysRoleMenu sysRoleMenu = new SysRoleMenu();
        revert(sysRoleMenuDto,sysRoleMenu);
        EntityWrapper<SysRoleMenu> wrapper = new EntityWrapper<>();
        wrapper.setEntity(sysRoleMenu);
        page = sysRoleMenuService.selectPage(page, wrapper);
        List<SysRoleMenuDto> sysRoleMenuDtoList = convertList(page.getRecords(), SysRoleMenuDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysRoleMenuDtoList);
        return pageDto;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void saveOrUpdate(Long roleId, List<Long> menuIdList) {
        //先删除角色与菜单关系
        sysRoleMenuService.saveOrUpdate(roleId,menuIdList);
    }

    @Override
    public List<Long> queryMenuIdList(Long roleId) {
        return sysRoleMenuService.queryMenuIdList(roleId);
    }

    @Override
    public int deleteBatchByRoleIds(Long[] roleIds){
        return sysRoleMenuService.deleteBatchByRoleId(roleIds);
    }

}
