
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysUserRole;
import io.platform.sys.biz.service.SysUserRoleService;
import io.platform.sys.dto.SysUserRoleDto;
import io.platform.sys.service.client.api.SysUserRoleServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysUserRoleServiceClientImpl extends BaseServiceClient<SysUserRole,SysUserRoleDto> implements SysUserRoleServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysUserRoleService sysUserRoleService;

    @Override
    public SysUserRoleDto queryObject(Long id) {
        SysUserRole sysUserRole = sysUserRoleService.selectById(id);
        SysUserRoleDto sysUserRoleDto = new SysUserRoleDto();
        BeanUtils.copyProperties(sysUserRole,sysUserRoleDto);
        return sysUserRoleDto;
    }

    @Override
    public List<SysUserRoleDto> queryList(Map<String, Object> map) {
        List<SysUserRole> sysUserRoleList = sysUserRoleService.selectByMap(map);
        return convertList(sysUserRoleList, SysUserRoleDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<SysUserRole> ew = new EntityWrapper<>();
        ew.allEq(map);
        return sysUserRoleService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(SysUserRoleDto sysUserRoleDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysUserRole sysUserRole = new SysUserRole();
            revert(sysUserRoleDto,sysUserRole);
            boolean flag=sysUserRoleService.insert(sysUserRole);
            if(!flag){
            result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysUserRoleDto sysUserRoleDto) {
        ExecuteResult<String> result = new ExecuteResult<>();
        try{
            SysUserRole sysUserRole = new SysUserRole();
            revert(sysUserRoleDto,sysUserRole);
            boolean flag=sysUserRoleService.updateById(sysUserRole);
            if(!flag){
            result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag=sysUserRoleService.deleteById(id);
            if(!flag){
            result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag=sysUserRoleService.deleteBatchIds(ids);
            if(!flag){
            result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysUserRoleDto> getPage(Page<SysUserRoleDto> pageDto, SysUserRoleDto sysUserRoleDto) {
        Page<SysUserRole> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        SysUserRole sysUserRole = new SysUserRole();
        revert(sysUserRoleDto,sysUserRole);
        EntityWrapper<SysUserRole> wrapper = new EntityWrapper<>();
        wrapper.setEntity(sysUserRole);
        page = sysUserRoleService.selectPage(page,wrapper);
        List<SysUserRoleDto> sysUserRoleDtoList = convertList(page.getRecords(), SysUserRoleDto.class);
        pageDto.setTotal(page.getTotal());
        pageDto.setRecords(sysUserRoleDtoList);
        return pageDto;
    }

    @Override
    public List<Long> queryRoleIdList(Long userId) {
        return sysUserRoleService.queryRoleIdList(userId);
    }

    @Override
    public SysUserRoleDto queryObjectByUserId(Long id) {
        EntityWrapper<SysUserRole> ew=new EntityWrapper<>();
        ew.eq("user_id",id);
        SysUserRole sysUserRole= sysUserRoleService.selectOne(ew);
        SysUserRoleDto sysUserRoleDto = new SysUserRoleDto();
        BeanUtils.copyProperties(sysUserRole,sysUserRoleDto);
        return sysUserRoleDto;
    }
}
