
package io.platform.sys.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.xiaoleilu.hutool.util.CollectionUtil;
import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.sys.biz.entity.SysUser;
import io.platform.sys.biz.entity.SysUserRole;
import io.platform.sys.biz.service.SysUserRoleService;
import io.platform.sys.biz.service.SysUserService;
import io.platform.sys.dto.SysUserDto;
import io.platform.sys.dto.SysUserRoleDto;
import io.platform.sys.service.client.api.SysUserServiceClient;
import org.apache.commons.lang.StringUtils;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Created by sevelli on 2017/8/31.
 */
@Component
@Service()
public class SysUserServiceClientImpl extends BaseServiceClient<SysUser, SysUserDto> implements SysUserServiceClient {
    private Logger logger = LoggerFactory.getLogger(getClass());
    @Resource
    private SysUserService sysUserService;
    @Resource
    private SysUserRoleService sysUserRoleService;

    @Override
    public SysUserDto queryObject(Long id) {
        SysUser sysUser = sysUserService.selectById(id);
        SysUserDto sysUserDto = new SysUserDto();
        BeanUtils.copyProperties(sysUser, sysUserDto);
        return sysUserDto;
    }

    @Override
    public List<SysUserDto> queryList(Map<String, Object> map) {
        List<SysUser> sysUserList = sysUserService.selectByMap(map);
        return convertList(sysUserList, SysUserDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        EntityWrapper<SysUser> ew = new EntityWrapper<>();
        ew.allEq(map);
        return sysUserService.selectCount(ew);
    }

    @Override
    public ExecuteResult<String> save(SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (!sysUserDto.getUsername().equals("admin")) {
                SysUser sysUser = new SysUser();
                revert(sysUserDto, sysUser);
                if (CollectionUtil.isNotEmpty(sysUserDto.getRoleIdList())) {
                    sysUser.setRoleIdList(sysUserDto.getRoleIdList());
                }
                boolean flag = sysUserService.insert(sysUser);
                Boolean isRole = true;
                if (sysUser.getRoleIdList() != null && !sysUser.getRoleIdList().isEmpty()) {
                    Long id = sysUserService.queryId(sysUserDto);
                    SysUserRole userRole = new SysUserRole();
                    userRole.setUserId(id);
                    for (Long attribute : sysUserDto.getRoleIdList()) {
                        userRole.setRoleId(attribute);
                    }
                    isRole = sysUserRoleService.insert(userRole);
                }

                if (!flag || !isRole) {
                    result.addErrorMessage("保存失败。");
                }
            } else {
                result.addErrorMessage("保存失败。无法使用此名称");
            }
        } catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysUserDto sysUserDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            if (!sysUserDto.getUsername().equals("admin")) {
                if (StringUtils.isNotBlank(sysUserDto.getPassword())) {
                    sysUserDto.setPassword(new Sha256Hash(sysUserDto.getPassword(), sysUserDto.getSalt()).toHex());
                }
                SysUser sysUser = sysUserService.selectById(sysUserDto.getUserId());
                revert(sysUserDto, sysUser);
                if (CollectionUtil.isNotEmpty(sysUserDto.getRoleIdList())) {
                    sysUser.setRoleIdList(sysUserDto.getRoleIdList());
                }
                sysUserService.update(sysUser);
                result.setSuccessMessage("更新成功");
            } else {
                result.setSuccessMessage("无法使用此名称");
            }
        } catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            boolean flag = sysUserService.deleteById(id);
            if (!flag) {
                result.addErrorMessage("删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try {
            Boolean isRole = true;
            for (Long attribute : ids) {
                isRole = sysUserRoleService.deleteByUserId(attribute);
            }
            boolean flag = sysUserService.deleteBatchIds(ids);
            if (!flag || !isRole) {
                result.addErrorMessage("批量删除失败。");
            }
        } catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysUserDto> getPage(Page<SysUserDto> pageDto, SysUserDto sysUserDto, SysUserDto userDto) {
        Page<SysUser> page = new Page<>(pageDto.getCurrent(), pageDto.getSize());
        page.setAsc(pageDto.isAsc());
        page.setOrderByField(pageDto.getOrderByField());
        page.setCondition(pageDto.getCondition());
        List<SysUserDto> sysUserDtoList = new ArrayList<>();
        EntityWrapper<SysUser> wrapper = new EntityWrapper<>();
        EntityWrapper<SysUser> sysUserEntityWrapper = new EntityWrapper<>();
        if (userDto.getUsername().equals("admin")) {
            SysUser sysUser = new SysUser();
            revert(sysUserDto, sysUser);
            wrapper.setEntity(sysUser);
            page = sysUserService.selectPage(page, wrapper);
            sysUserDtoList = convertList(page.getRecords(), SysUserDto.class);
            pageDto.setTotal(page.getTotal());
        } else {
            wrapper.eq("user_id", userDto.getUserId()).or().eq("create_user_id", userDto.getUserId()).last("LIMIT 0,5");
            sysUserEntityWrapper.eq("user_id", userDto.getUserId()).or().eq("create_user_id", userDto.getUserId());
            List<SysUser> sysUsers = sysUserService.selectList(wrapper);
            if (sysUsers.size() != 0) {
                for (SysUser sysUser : sysUsers) {
                    SysUserDto userDto1 = new SysUserDto();
                    convert(sysUser, userDto1);
                    sysUserDtoList.add(userDto1);
                }
            }
            int number = sysUserService.selectCount(sysUserEntityWrapper);
            pageDto.setTotal(number);
        }
        pageDto.setRecords(sysUserDtoList);
        return pageDto;
    }

    @Override
    public SysUserDto selectByUserName(String username) {
        SysUser sysUser = sysUserService.queryByUserName(username);

        SysUserDto sysUserDto = new SysUserDto();
        convert(sysUser, sysUserDto);
        return sysUserDto;
    }

    @Override
    public boolean updatePassword(Long userId, String password, String newPassword) {
        return sysUserService.updatePassword(userId, password, newPassword);
    }

    @Override
    public List<String> queryAllPerms(Long userId) {
        return sysUserService.queryAllPerms(userId);
    }

    @Override
    public List<Long> queryAllMenuId(Long userId) {
        return sysUserService.queryAllMenuId(userId);
    }
}
